package cz.moneta.test.dsl.mwf.createcustomer;

import cz.moneta.test.harness.support.mwf.ApiVersion;
import cz.moneta.test.harness.support.mwf.MwfRequest;
import cz.moneta.test.harness.support.mwf.Parameter;

public interface MWF109 extends MwfRequest<MWF109, MWF109Response> {

    @Parameter(name = "Adresat")
    MWF109 Adresat(String Adresat);
    @Parameter(name = "CO")
    MWF109 Co(String Co);
    @Parameter(name = "CP")
    MWF109 Cp(String Cp);
    @Parameter(name = "CisloPasu")
    MWF109 CisloPasu(String CisloPasu);
    @Parameter(name = "CistyMesicniPrijem")
    MWF109 CistyMesicniPrijem(Double CistyMesicniPrijem);
    @Parameter(name = "Ctvrt")
    MWF109 Ctvrt(String Ctvrt);
    @Parameter(name = "DatumExpiraceKontaktnichUdaju")
    MWF109 DatumExpiraceKontaktnichUdaju(java.util.Date DatumExpiraceKontaktnichUdaju);
    @Parameter(name = "DatumExpiracePotvrzeniStudent")
    MWF109 DatumExpiracePotvrzeniStudent(java.util.Date DatumExpiracePotvrzeniStudent);
    @Parameter(name = "DatumNarozeni")
    MWF109 DatumNarozeni(java.util.Date DatumNarozeni);
    @Parameter(name = "DatumNastehovani")
    MWF109 DatumNastehovani(java.util.Date DatumNastehovani);
    @Parameter(name = "DatumPotvrzeniPrijmu")
    MWF109 DatumPotvrzeniPrijmu(java.util.Date DatumPotvrzeniPrijmu);
    @Parameter(name = "DatumZalozeniCIFu")
    MWF109 DatumZalozeniCIFu(java.util.Date DatumZalozeniCIFu);
    @Parameter(name = "DruhBydleni")
    MWF109 DruhBydleni(String DruhBydleni);
    @Parameter(name = "DruhKlienta")
    MWF109 DruhKlienta(String DruhKlienta);
    @Parameter(name = "DruhPrijmuKlienta")
    MWF109 DruhPrijmuKlienta(String DruhPrijmuKlienta);
    @Parameter(name = "DruhaStatniPrislusnost")
    MWF109 DruhaStatniPrislusnost(String DruhaStatniPrislusnost);
    @Parameter(name = "DruheJmeno")
    MWF109 DruheJmeno(String DruheJmeno);
    @Parameter(name = "EMail")
    MWF109 EMail(String EMail);
    @Parameter(name = "EkonomickySektor")
    MWF109 EkonomickySektor(String EkonomickySektor);
    @Parameter(name = "FATCA_Flag")
    MWF109 FATCAFlag(String FATCAFlag);
    @Parameter(name = "Funkce")
    MWF109 Funkce(String Funkce);
    @Parameter(name = "JinyOsobniDoklad1Cislo")
    MWF109 JinyOsobniDoklad1Cislo(String JinyOsobniDoklad1Cislo);
    @Parameter(name = "JinyOsobniDoklad1Platnost")
    MWF109 JinyOsobniDoklad1Platnost(java.util.Date JinyOsobniDoklad1Platnost);
    @Parameter(name = "JinyOsobniDoklad1StatVydal")
    MWF109 JinyOsobniDoklad1StatVydal(String JinyOsobniDoklad1StatVydal);
    @Parameter(name = "JinyOsobniDoklad1Typ")
    MWF109 JinyOsobniDoklad1Typ(String JinyOsobniDoklad1Typ);
    @Parameter(name = "JinyOsobniDoklad2Cislo")
    MWF109 JinyOsobniDoklad2Cislo(String JinyOsobniDoklad2Cislo);
    @Parameter(name = "JinyOsobniDoklad2Platnost")
    MWF109 JinyOsobniDoklad2Platnost(java.util.Date JinyOsobniDoklad2Platnost);
    @Parameter(name = "JinyOsobniDoklad2StatVydal")
    MWF109 JinyOsobniDoklad2StatVydal(String JinyOsobniDoklad2StatVydal);
    @Parameter(name = "JinyOsobniDoklad2Typ")
    MWF109 JinyOsobniDoklad2Typ(String JinyOsobniDoklad2Typ);
    @Parameter(name = "KlasifikaceKlienta")
    MWF109 KlasifikaceKlienta(String KlasifikaceKlienta);
    @Parameter(name = "KodObchodnihoMista")
    MWF109 KodObchodnihoMista(String KodObchodnihoMista);
    @Parameter(name = "MistoNarozeni")
    MWF109 MistoNarozeni(String MistoNarozeni);
    @Parameter(name = "NazevZamestnavatele")
    MWF109 NazevZamestnavatele(String NazevZamestnavatele);
    @Parameter(name = "NejvyssiDosazeneVzdelani")
    MWF109 NejvyssiDosazeneVzdelani(String NejvyssiDosazeneVzdelani);
    @Parameter(name = "NoEmailFlag")
    MWF109 NoEmailFlag(Long NoEmailFlag);
    @Parameter(name = "OPStatVydal")
    MWF109 OPStatVydal(String OPStatVydal);
    @Parameter(name = "Obec")
    MWF109 Obec(String Obec);
    @Parameter(name = "Osloveni")
    MWF109 Osloveni(String Osloveni);
    @Parameter(name = "OsobniBanker")
    MWF109 OsobniBanker(String OsobniBanker);
    @Parameter(name = "PSC")
    MWF109 Psc(String Psc);
    @Parameter(name = "PasStatVydal")
    MWF109 PasStatVydal(String PasStatVydal);
    @Parameter(name = "PlatnostKontaktnichUdaju")
    MWF109 PlatnostKontaktnichUdaju(String PlatnostKontaktnichUdaju);
    @Parameter(name = "PlatnostOPdo")
    MWF109 PlatnostOPdo(java.util.Date PlatnostOPdo);
    @Parameter(name = "PlatnostPasuDo")
    MWF109 PlatnostPasuDo(java.util.Date PlatnostPasuDo);
    @Parameter(name = "PocetVyzivovanychDeti")
    MWF109 PocetVyzivovanychDeti(Long PocetVyzivovanychDeti);
    @Parameter(name = "Pohlavi")
    MWF109 Pohlavi(String Pohlavi);
    @Parameter(name = "Posta")
    MWF109 Posta(String Posta);
    @Parameter(name = "PotvrzeniStudent")
    MWF109 PotvrzeniStudent(String PotvrzeniStudent);
    @Parameter(name = "Povolani")
    MWF109 Povolani(String Povolani);
    @Parameter(name = "Prijmeni")
    MWF109 Prijmeni(String Prijmeni);
    @Parameter(name = "PrijmovaSkupina")
    MWF109 PrijmovaSkupina(String PrijmovaSkupina);
    @Parameter(name = "PrvniJmeno")
    MWF109 PrvniJmeno(String PrvniJmeno);
    @Parameter(name = "Rezidence")
    MWF109 Rezidence(String Rezidence);
    @Parameter(name = "RodinnyStav")
    MWF109 RodinnyStav(String RodinnyStav);
    @Parameter(name = "RodneCislo")
    MWF109 RodneCislo(String RodneCislo);
    @Parameter(name = "SerieACisloOP")
    MWF109 SerieACisloOP(String SerieACisloOP);
    @Parameter(name = "SocialneEkonomickaSkupina")
    MWF109 SocialneEkonomickaSkupina(String SocialneEkonomickaSkupina);
    @Parameter(name = "SpravniCelek")
    MWF109 SpravniCelek(String SpravniCelek);
    @Parameter(name = "StatniPrislusnost")
    MWF109 StatniPrislusnost(String StatniPrislusnost);
    @Parameter(name = "TIN")
    MWF109 Tin(String Tin);
    @Parameter(name = "TelefonDalsi")
    MWF109 TelefonDalsi(String TelefonDalsi);
    @Parameter(name = "TelefonDalsiPredvolba")
    MWF109 TelefonDalsiPredvolba(String TelefonDalsiPredvolba);
    @Parameter(name = "TelefonDomu")
    MWF109 TelefonDomu(String TelefonDomu);
    @Parameter(name = "TelefonDomuPredvolba")
    MWF109 TelefonDomuPredvolba(String TelefonDomuPredvolba);
    @Parameter(name = "TelefonMobilni")
    MWF109 TelefonMobilni(String TelefonMobilni);
    @Parameter(name = "TelefonMobilniPredvolba")
    MWF109 TelefonMobilniPredvolba(String TelefonMobilniPredvolba);
    @Parameter(name = "TelefonZamestnani")
    MWF109 TelefonZamestnani(String TelefonZamestnani);
    @Parameter(name = "TelefonZamestnaniPredvolba")
    MWF109 TelefonZamestnaniPredvolba(String TelefonZamestnaniPredvolba);
    @Parameter(name = "Titul")
    MWF109 Titul(String Titul);
    @Parameter(name = "TitulZaJmenem")
    MWF109 TitulZaJmenem(String TitulZaJmenem);
    @Parameter(name = "TypDruhehoDokladu")
    MWF109 TypDruhehoDokladu(String TypDruhehoDokladu);
    @Parameter(name = "TypKlienta")
    MWF109 TypKlienta(String TypKlienta);
    @Parameter(name = "Ulice")
    MWF109 Ulice(String Ulice);
    @Parameter(name = "UlozPSCBezKontroly")
    MWF109 UlozPSCBezKontroly(String UlozPSCBezKontroly);
    @Parameter(name = "Urednik")
    MWF109 Urednik(String Urednik);
    @Parameter(name = "VztahKBance")
    MWF109 VztahKBance(String VztahKBance);
    @Parameter(name = "ZAMCO")
    MWF109 Zamco(String Zamco);
    @Parameter(name = "ZAMCP")
    MWF109 Zamcp(String Zamcp);
    @Parameter(name = "ZAMICO")
    MWF109 Zamico(String Zamico);
    @Parameter(name = "ZAMPSC")
    MWF109 Zampsc(String Zampsc);
    @Parameter(name = "ZAMPosta")
    MWF109 ZAMPosta(String ZAMPosta);
    @Parameter(name = "ZAMUlice")
    MWF109 ZAMUlice(String ZAMUlice);
    @Parameter(name = "ZamObec")
    MWF109 ZamObec(String ZamObec);
    @Parameter(name = "ZamestnanOd")
    MWF109 ZamestnanOd(java.util.Date ZamestnanOd);
    @Parameter(name = "Zeme")
    MWF109 Zeme(String Zeme);
    @Parameter(name = "ZemeNarozeni")
    MWF109 ZemeNarozeni(String ZemeNarozeni);
    @Parameter(name = "ZkraceneJmeno")
    MWF109 ZkraceneJmeno(String ZkraceneJmeno);
    @Parameter(name = "ZuzeneSJM")
    MWF109 ZuzeneSJM(String ZuzeneSJM);
}
